#!/bin/bash

export LANG=C

DESTDIR=dist

IRON_VERSION=1.1a1
PY_VERSION=2.4.4
ET_VERSION=1.2.6-20050316
WSGIREF_PY_VERSION=2.5
CRYPTO_VERSION=2.0.1
PARAMIKO_VERSION=1.6.4
PYFLAKES_VERSION=0.2.1

tag () {
  echo -n r
  echo $1 | tr -d .
}

PY_TAG=`tag $PY_VERSION`
WSGIREF_PY_TAG=`tag $WSGIREF_PY_VERSION`

FEPY=https://svn.sourceforge.net/svnroot/fepy/trunk
PYDOTORG=http://svn.python.org/projects/python
STDLIB=$PYDOTORG/tags/$PY_TAG/Lib
WSGIREF=$PYDOTORG/tags/$WSGIREF_PY_TAG/Lib/wsgiref

update () {
  if [ ! -d $2 ]; then
    svn checkout $1 $2
  else
    svn update $2
  fi
}

echo 'Updating FePy'
update $FEPY fepy

echo 'Updating Python standard library'
update $STDLIB lib

echo 'Updating WSGI reference implementation'
update $WSGIREF wsgiref

echo 'Unpacking IronPython'
rm -rf $DESTDIR
unzip -q files/IronPython-$IRON_VERSION-Src.zip

# Workaround 1.1a1 extraction directory oddness
IRONDIR=IronPython-$IRON_VERSION
if [ ! -d $IRONDIR ]; then
  IRONDIR=${IRONDIR%a*}
fi

mv $IRONDIR $DESTDIR

for name in fepy/patches/$IRON_VERSION/patch-*; do
  echo Applying ${name##*/}
  patch -d $DESTDIR -p1 --quiet < $name
done

echo 'Compiling IronPython'
make -C $DESTDIR/Src CSC='gmcs -warn:0'

get () {
  if [ -d $1 ]; then
    svn export $1 $2
  else
    dir=`dirname $2`
    if [ ! -z $dir ]; then
      mkdir -p $dir
    fi
    cp $1.py $2.py
  fi
}

echo 'Copying Python standard library'
for name in `cat fepy/script/mlist`; do
  get lib/$name $DESTDIR/Lib/$name
done

# wsgiref
svn export wsgiref $DESTDIR/Lib/wsgiref

for name in fepy/patches/stdlib/$PY_VERSION/patch-*; do
  echo Applying ${name##*/}
  patch -d $DESTDIR/Lib -p0 --quiet < $name
done

for name in `cat fepy/script/tlist`; do
  echo "Creating empty $name.py"
  touch $DESTDIR/Lib/$name.py
done

echo 'Updating site.py'
cat fepy/lib/site.py >> $DESTDIR/Lib/site.py

echo 'Copying FePy library'
for name in `cat fepy/script/plist`; do
  if [ $name == fepy ]; then
    continue
  else
    get fepy/lib/$name $DESTDIR/Lib/$name
  fi
done

echo 'Copying FePy options'
get fepy/fepy $DESTDIR/Lib/fepy

echo 'Copying FePy DB-API'
for name in `cat fepy/script/dlist`; do
  get fepy/dbapi/$name $DESTDIR/Lib/$name
done

echo 'Copying 3rd party library'
# BeautifulSoup
cp files/BeautifulSoup.py $DESTDIR/Lib
# elementtree
tar zxf files/elementtree-$ET_VERSION.tar.gz
dir=elementtree-$ET_VERSION
cp -r $dir/elementtree $DESTDIR/Lib
rm -rf $dir
# pycrypto
tar zxf files/pycrypto-$CRYPTO_VERSION.tar.gz
mkdir $DESTDIR/Lib/Crypto
dir=pycrypto-$CRYPTO_VERSION
cp $dir/__init__.py $DESTDIR/Lib/Crypto
cp -r $dir/{Cipher,Hash,Protocol,PublicKey,Util} $DESTDIR/Lib/Crypto
rm -rf $dir
# paramiko
tar zxf files/paramiko-$PARAMIKO_VERSION.tar.gz
dir=paramiko-$PARAMIKO_VERSION
cp -r $dir/paramiko $DESTDIR/Lib
rm -rf $dir
# Pyflakes
tar zxf files/pyflakes-$PYFLAKES_VERSION.tar.gz
dir=pyflakes-$PYFLAKES_VERSION
cp -r $dir/pyflakes $DESTDIR/Lib
cp $dir/bin/pyflakes $DESTDIR
rm -rf $dir

# License
rm -f $DESTDIR/License.Rtf
cp ../website/license.html $DESTDIR/License.html

rm -rf $DESTDIR/Doc $DESTDIR/Src $DESTDIR/Tutorial
